@@ -1,5 +1,5 @@
 /*
- * $Id: shoutcast.c,v 1.141.2.1 2004/05/11 10:54:34 jylefort Exp $
+ * $Id: shoutcast.c,v 1.141.2.2 2004/05/11 15:40:41 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,7 +34,7 @@
 #include "config.h"
 #include <string.h>
 #include <stdlib.h>
-#include <glib/gi18n-lib.h>
+#include "gettext.h"
 #include "streamtuner.h"
 #include "art/shoutcast.h"
 
