@@ -1,5 +1,5 @@
 /*
- * $Id: sg-util.c,v 1.21.2.1 2004/05/11 10:54:34 jylefort Exp $
+ * $Id: sg-util.c,v 1.21.2.2 2004/07/24 16:17:26 jylefort Exp $
  *
  * Copyright (c) 2003 Jean-Yves Lefort
  * All rights reserved.
@@ -65,6 +65,17 @@ sg_str_sentencize (const char *str)
   return sentencized;
 }
 
+void
+sg_pointers_free (GSList *pointers)
+{
+  GSList *l;
+
+  SG_LIST_FOREACH(l, pointers)
+    g_free(l->data);
+
+  g_slist_free(pointers);
+}
+
 void
 sg_objects_free (GSList *objects)
 {
@@ -144,6 +155,48 @@ sg_value_equal (const GValue *value1, const GValue *value2)
   return equal;
 }
 
+int
+sg_utf8_strcmp (const char *s1, const char *s2)
+{
+  int cmp;
+  char *normalized_s1;
+  char *normalized_s2;
+
+  g_return_val_if_fail(s1 != NULL, 0);
+  g_return_val_if_fail(s2 != NULL, 0);
+
+  normalized_s1 = g_utf8_normalize(s1, -1, G_NORMALIZE_ALL);
+  normalized_s2 = g_utf8_normalize(s2, -1, G_NORMALIZE_ALL);
+  
+  cmp = strcmp(normalized_s1, normalized_s2);
+
+  g_free(normalized_s1);
+  g_free(normalized_s2);
+
+  return cmp;
+}
+
+gboolean
+sg_utf8_strcontains (const char *big, const char *little)
+{
+  gboolean contains;
+  char *normalized_big;
+  char *normalized_little;
+
+  g_return_val_if_fail(big != NULL, FALSE);
+  g_return_val_if_fail(little != NULL, FALSE);
+
+  normalized_big = g_utf8_normalize(big, -1, G_NORMALIZE_ALL);
+  normalized_little = g_utf8_normalize(little, -1, G_NORMALIZE_ALL);
+
+  contains = strstr(normalized_big, normalized_little) != NULL;
+
+  g_free(normalized_big);
+  g_free(normalized_little);
+
+  return contains;
+}
+
 gboolean
 sg_utf8_strcasecontains (const char *big, const char *little)
 {
