@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-auth-dialog.c,v 1.24.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: sgtk-auth-dialog.c,v 1.24.2.3 2004/07/24 17:17:55 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -35,7 +35,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <stdarg.h>
-#include "art/auth.h"
 #include "gettext.h"
 #include "sgtk-auth-dialog.h"
 #include "sgtk-hig.h"
@@ -97,30 +96,10 @@ static void
 sgtk_auth_dialog_class_init (sGtkAuthDialogClass *class)
 {
   GObjectClass *object_class = G_OBJECT_CLASS(class);
-  GtkIconFactory *factory;
-  GtkIconSet *icon_set;
-  GdkPixbuf *pixbuf;
   
   parent_class = g_type_class_peek_parent(class);
 
   object_class->finalize = sgtk_auth_dialog_finalize;
-
-  factory = gtk_icon_factory_new();
-  gtk_icon_factory_add_default(factory);
-
-  pixbuf = gdk_pixbuf_new_from_inline(sizeof(art_auth),
-				      art_auth,
-				      FALSE,
-				      NULL);
-  g_assert(pixbuf != NULL);
-
-  icon_set = gtk_icon_set_new_from_pixbuf(pixbuf);
-  g_object_unref(pixbuf);
-
-  gtk_icon_factory_add(factory, SGTK_STOCK_AUTH, icon_set);
-  gtk_icon_set_unref(icon_set);
-
-  g_object_unref(factory);
 }
 
 static void
@@ -139,7 +118,7 @@ sgtk_auth_dialog_init (sGtkAuthDialog *dialog)
   gtk_window_set_default(GTK_WINDOW(dialog), ok);
 
   gtk_image_set_from_stock(GTK_IMAGE(SGTK_ALERT_DIALOG(dialog)->image),
-			   SGTK_STOCK_AUTH,
+			   GTK_STOCK_DIALOG_AUTHENTICATION,
 			   GTK_ICON_SIZE_DIALOG);
 
   dialog->priv->label = gtk_label_new(NULL);
