@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-util.c,v 1.14.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: sgtk-util.c,v 1.14.2.3 2004/07/24 16:17:26 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,6 +34,7 @@
 #include "config.h"
 #include <gtk/gtk.h>
 #include "gettext.h"
+#include "sgtk-util.h"
 
 /*** function declarations ***************************************************/
 
@@ -93,3 +94,65 @@ sgtk_widget_activate_h (GtkWidget *widget, gpointer data)
 
   gtk_widget_grab_focus(next);
 }
+
+gboolean
+sgtk_tree_model_get_iter_last (GtkTreeModel *model, GtkTreeIter *iter)
+{
+  gboolean status;
+  gboolean valid;
+  GtkTreeIter tmp_iter;
+
+  g_return_val_if_fail(GTK_IS_TREE_MODEL(model), FALSE);
+  g_return_val_if_fail(iter != NULL, FALSE);
+
+  status = valid = gtk_tree_model_get_iter_first(model, &tmp_iter);
+  while (valid)
+    {
+      *iter = tmp_iter;
+      valid = gtk_tree_model_iter_next(model, &tmp_iter);
+    }
+
+  return status;
+}
+
+gboolean
+sgtk_tree_model_iter_prev (GtkTreeModel *model, GtkTreeIter *iter)
+{
+  GtkTreePath *path;
+  gboolean status;
+
+  g_return_val_if_fail(GTK_IS_TREE_MODEL(model), FALSE);
+  g_return_val_if_fail(iter != NULL, FALSE);
+  
+  path = gtk_tree_model_get_path(model, iter);
+  status = gtk_tree_path_prev(path);
+  if (status)
+    {
+      status = gtk_tree_model_get_iter(model, iter, path);
+      g_return_val_if_fail(status == TRUE, FALSE);
+    }
+  gtk_tree_path_free(path);
+
+  return status;
+}
+
+gboolean
+sgtk_tree_model_iter_move (GtkTreeModel *model,
+			   GtkTreeIter *iter,
+			   sGtkDirection direction)
+{
+  g_return_val_if_fail(GTK_IS_TREE_MODEL(model), FALSE);
+  g_return_val_if_fail(iter != NULL, FALSE);
+  
+  switch (direction)
+    {
+    case SGTK_PREVIOUS:
+      return sgtk_tree_model_iter_prev(model, iter);
+
+    case SGTK_NEXT:
+      return gtk_tree_model_iter_next(model, iter);
+
+    default:
+      g_return_val_if_reached(FALSE);
+    }
+}
