@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-util.h,v 1.13 2004/03/13 18:51:01 jylefort Exp $
+ * $Id: sgtk-util.h,v 1.13.2.1 2004/07/24 16:17:26 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -42,6 +42,12 @@ typedef enum
   SGTK_RESPONSE_NEXT
 } sGtkResponseType;
 
+typedef enum
+{
+  SGTK_PREVIOUS,
+  SGTK_NEXT
+} sGtkDirection;
+
 void		sgtk_flush			(void);
 char		*sgtk_translate_func		(const char	*path,
 						 gpointer	data);
@@ -49,5 +55,12 @@ GdkPixbuf	*sgtk_pixbuf_scale		(GdkPixbuf	*pixbuf,
 						 GtkIconSize	size);
 void		sgtk_widget_set_next_widget	(GtkWidget	*widget,
 						 GtkWidget	*next);
+gboolean	sgtk_tree_model_get_iter_last	(GtkTreeModel	*model,
+						 GtkTreeIter	*iter);
+gboolean	sgtk_tree_model_iter_prev	(GtkTreeModel	*model,
+						 GtkTreeIter	*iter);
+gboolean	sgtk_tree_model_iter_move	(GtkTreeModel	*model,
+						 GtkTreeIter	*iter,
+						 sGtkDirection	direction);
 
 #endif /* _SGTK_UTIL_H */
