@@ -1,5 +1,5 @@
 /*
- * $Id: st-applications-tab.c,v 1.7.2.1 2004/05/11 10:54:34 jylefort Exp $
+ * $Id: st-applications-tab.c,v 1.7.2.2 2004/05/11 15:40:41 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,9 +32,9 @@
  */
 
 #include "config.h"
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include "art/applications_preferences.h"
+#include "gettext.h"
 #include "sg-util.h"
 #include "st-applications-tab.h"
 #include "st-preferences-tab.h"
