@@ -1,5 +1,5 @@
 /*
- * $Id: st-category-bag.c,v 1.21.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-category-bag.c,v 1.21.2.2 2004/07/23 16:46:16 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -211,3 +211,20 @@ st_category_bag_set_or_unset_remarkable (STCategoryBag *bag)
   else
     st_handler_remove_remarkable_category(bag->handler, bag);
 }
+
+void
+st_category_bag_select (STCategoryBag *bag)
+{
+  STCategoryBag *selected_bag;
+
+  g_return_if_fail(ST_IS_CATEGORY_BAG(bag));
+
+  selected_bag = st_handler_get_selected_category(bag->handler);
+  if (selected_bag)
+    {
+      st_category_bag_unset_flags(selected_bag, ST_CATEGORY_BAG_SELECTED);
+      g_object_unref(selected_bag);
+    }
+
+  st_category_bag_set_flags(bag, ST_CATEGORY_BAG_SELECTED);
+}
