@@ -1,5 +1,5 @@
 /*
- * $Id: st-category-view.c,v 1.68.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: st-category-view.c,v 1.68.2.6 2004/07/24 16:23:09 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -251,26 +251,11 @@ st_category_view_selection_changed_h (GtkTreeSelection *selection,
   if (gtk_tree_selection_get_selected(selection, &model, &iter))
     {
       STCategoryBag *bag;
-      STCategoryBag *selected_bag;
 
       gtk_tree_model_get(model, &iter, ST_CATEGORY_STORE_COLUMN_BAG, &bag, -1);
-
-      /* unset the old selection */
-
-      selected_bag = st_handler_get_selected_category(bag->handler);
-      if (selected_bag)
-	{
-	  st_category_bag_unset_flags(selected_bag, ST_CATEGORY_BAG_SELECTED);
-	  g_object_unref(selected_bag);
-	}
-
-      /* set the new selection */
-
-      st_category_bag_set_flags(bag, ST_CATEGORY_BAG_SELECTED);
+      st_category_bag_select(bag);
       g_object_unref(bag);
 
-      /* emit the signal */
-
       g_signal_emit(view, category_view_signals[SELECTION_CHANGED], 0);
     }
 }
@@ -383,3 +368,22 @@ st_category_view_model_category_appended_h (STCategoryStore *store,
       g_signal_handler_unblock(selection, view->priv->selection_changed_hid);
     }
 }
+
+/*
+ * Select the iter belonging to category BAG, but does not trigger the
+ * emission of a selection-changed signal.
+ */
+void
+st_category_view_select_category (STCategoryView *view, STCategoryBag *bag)
+{
+  GtkTreeSelection *selection;
+
+  g_return_if_fail(ST_IS_CATEGORY_VIEW(view));
+  g_return_if_fail(ST_IS_CATEGORY_BAG(bag));
+
+  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
+
+  g_signal_handler_block(selection, view->priv->selection_changed_hid);
+  gtk_tree_selection_select_iter(selection, &bag->iter);
+  g_signal_handler_unblock(selection, view->priv->selection_changed_hid);
+}
