@@ -1,5 +1,5 @@
 /*
- * $Id: st-config-load.c,v 1.35.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: st-config-load.c,v 1.35.2.4 2004/07/24 16:53:40 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -80,6 +80,10 @@ enum {
   STATEMENT_OPTIONS_GALEON_THEMES_USER_DIR,	/* obsolete */
   STATEMENT_OPTIONS_SELECTED_HANDLER,
   STATEMENT_OPTIONS_ALWAYS_REFRESH,
+  STATEMENT_OPTIONS_FIND_TOKEN,
+  STATEMENT_OPTIONS_FIND_CASE_SENSITIVE,
+  STATEMENT_OPTIONS_FIND_WRAP_AROUND,
+  STATEMENT_OPTIONS_FIND_HISTORY,
 
   STATEMENT_ACTION,
   STATEMENT_ACTION_COMMAND,
@@ -250,6 +254,22 @@ static SGParserDefinition config_definitions[] = {
     STATEMENT_OPTIONS,	STATEMENT_OPTIONS_ALWAYS_REFRESH,
     "always_refresh",	FALSE,		G_TYPE_BOOLEAN
   }, 
+  {
+    STATEMENT_OPTIONS,	STATEMENT_OPTIONS_FIND_TOKEN,
+    "find_token",	FALSE,		G_TYPE_STRING
+  }, 
+  {
+    STATEMENT_OPTIONS,	STATEMENT_OPTIONS_FIND_CASE_SENSITIVE,
+    "find_case_sensitive",	FALSE,	G_TYPE_BOOLEAN
+  }, 
+  {
+    STATEMENT_OPTIONS,	STATEMENT_OPTIONS_FIND_WRAP_AROUND,
+    "find_wrap_around",		FALSE,	G_TYPE_BOOLEAN
+  }, 
+  {
+    STATEMENT_OPTIONS,	STATEMENT_OPTIONS_FIND_HISTORY,
+    "find_history",	TRUE,		G_TYPE_NONE
+  }, 
   {
     0,			STATEMENT_ACTION,
     "action",		TRUE,		G_TYPE_STRING
@@ -315,6 +335,8 @@ static SGParserDefinition config_definitions[] = {
   
 /*** function declarations ***************************************************/
 
+static void st_config_load_find_history              (STConfigLoadInfo *info);
+
 static void st_config_load_handler_begin	     (STConfigLoadInfo *info);
 static void st_config_load_handler_end		     (STConfigLoadInfo *info);
 
@@ -504,6 +526,19 @@ st_config_load (const char *filename, GError **err)
 	      st_settings.always_refresh = g_value_get_boolean(&info.statement->value);
 	      break;
 
+	    case STATEMENT_OPTIONS_FIND_TOKEN:
+	      g_free(st_settings.find_token);
+	      st_settings.find_token = g_value_dup_string(&info.statement->value);
+	      break;
+
+	    case STATEMENT_OPTIONS_FIND_CASE_SENSITIVE:
+	      st_settings.find_case_sensitive = g_value_get_boolean(&info.statement->value);
+	      break;
+
+	    case STATEMENT_OPTIONS_FIND_WRAP_AROUND:
+	      st_settings.find_wrap_around = g_value_get_boolean(&info.statement->value);
+	      break;
+
 	    case STATEMENT_ACTION:
 	      info.action = g_value_dup_string(&info.statement->value);
 	      break;
@@ -567,6 +602,10 @@ st_config_load (const char *filename, GError **err)
 	{
 	  switch (SG_PARSER_SCOPE(info.parser))
 	    {
+	    case STATEMENT_OPTIONS_FIND_HISTORY:
+	      st_config_load_find_history(&info);
+	      break;
+
 	    case STATEMENT_HANDLER_FIELDS_WIDTH:
 	      st_config_load_handler_field_width(&info);
 	      break;
@@ -591,6 +630,21 @@ st_config_load (const char *filename, GError **err)
   return TRUE;
 }
 
+static void
+st_config_load_find_history (STConfigLoadInfo *info)
+{
+  if (! G_VALUE_HOLDS_STRING(&info->statement->value))
+    {
+      sg_parser_warn(info->parser, _("expected string value"));
+      return;
+    }
+
+  if (g_slist_length(st_settings.find_history) < ST_SETTINGS_FIND_HISTORY_MAX_LENGTH)
+    st_settings.find_history = g_slist_append(st_settings.find_history, g_value_dup_string(&info->statement->value));
+  else
+    sg_parser_warn(info->parser, _("too many find history tokens"));
+}
+
 static void
 st_config_load_handler_begin (STConfigLoadInfo *info)
 {
