@@ -1,5 +1,5 @@
 /*
- * $Id: st-general-tab.c,v 1.27.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: st-general-tab.c,v 1.27.2.3 2004/07/25 18:39:37 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -136,7 +136,7 @@ st_general_tab_init (STGeneralTab *tab)
   save_automatic = gtk_check_button_new_with_mnemonic(_("_Save session upon exit"));
   gtk_tooltips_set_tip(tab->priv->tooltips, save_automatic,
 		       _("If this option is enabled, your session will be saved upon exit.\n"
-			 "Otherwise, you'll be asked what to do."),
+			 "Otherwise, you will be asked what to do."),
 		       NULL);
 
   st_preferences_bind_boolean(GTK_TOGGLE_BUTTON(splash_enabled), &st_settings.splash_enabled);
