@@ -1,5 +1,5 @@
 /*
- * $Id: st-network-tab.c,v 1.40.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-network-tab.c,v 1.40.2.3 2004/07/25 18:39:37 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -207,7 +207,7 @@ st_network_tab_init (STNetworkTab *tab)
   gtk_tooltips_set_tip(tab->priv->tooltips, tab->priv->password_entry,
 		       _("The password used to authenticate yourself.\n"
 			 "\n"
-			 "If left blank, you'll be prompted for a password upon each transfer."),
+			 "If left blank, you will be prompted for a password upon each transfer."),
 		       NULL);
 
   gtk_misc_set_alignment(GTK_MISC(tab->priv->type_label), 1, 0.5);
