@@ -1,5 +1,5 @@
 /*
- * $Id: st-plugins.c,v 1.14.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-plugins.c,v 1.14.2.3 2004/07/25 18:42:04 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -117,7 +117,7 @@ st_plugins_scan (const char *dirname, GError **err)
 	      char *secondary;
 	      char *normalized;
 
-	      secondary = g_strdup_printf(_("Plugin <i>%s</i> couldn't be loaded: %s"),
+	      secondary = g_strdup_printf(_("Plugin <i>%s</i> could not be loaded: %s"),
 					  pathname, load_err->message);
 	      normalized = st_dialog_normalize(secondary);
 
