@@ -1,5 +1,5 @@
 /*
- * $Id: st-settings.c,v 1.27.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-settings.c,v 1.27.2.4 2004/07/25 18:42:04 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -63,7 +63,7 @@ st_settings_init (const char *custom_private_dir)
   if (! (home = g_get_home_dir()))
     {
       st_error_dialog(_("A fatal error has occurred."),
-		      _("Couldn't find your home directory."));
+		      _("Could not find your home directory."));
       exit(1);
     }
 
@@ -115,4 +115,9 @@ st_settings_init (const char *custom_private_dir)
   st_settings.selected_handler_name = NULL;
   
   st_settings.always_refresh = FALSE;
+
+  st_settings.find_token = g_strdup("");
+  st_settings.find_history = NULL;
+  st_settings.find_case_sensitive = FALSE;
+  st_settings.find_wrap_around = FALSE;
 }
