@@ -1,5 +1,5 @@
 /*
- * $Id: st-settings.h,v 1.20 2004/03/26 19:02:43 jylefort Exp $
+ * $Id: st-settings.h,v 1.20.2.2 2004/07/24 16:53:40 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -38,6 +38,8 @@
 #include "st-settings-api.h"
 #include "st-transfer.h"
 
+#define ST_SETTINGS_FIND_HISTORY_MAX_LENGTH	10
+
 /*
  * All strings are expected to be always dynamically allocated.
  * They must be g_free()d before assigning a new value to them.
@@ -90,6 +92,11 @@ typedef struct
   char			*selected_handler_name;
 
   gboolean		always_refresh;
+
+  char			*find_token;
+  GSList		*find_history;
+  gboolean		find_case_sensitive;
+  gboolean		find_wrap_around;
 } STSettings;
 
 extern STSettings st_settings;
