@@ -1,5 +1,5 @@
 /*
- * $Id: st-shell.c,v 1.170.2.3 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-shell.c,v 1.170.2.12 2004/07/26 15:28:41 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -43,6 +43,7 @@
 #include "st-browser-tab.h"
 #include "st-settings.h"
 #include "sgtk-message-dialog.h"
+#include "sgtk-find-dialog.h"
 #include "st-dialog-api.h"
 #include "st-action.h"
 #include "st-about-dialog.h"
@@ -73,6 +74,11 @@ struct _STShellPrivate
   /* menubar */
   GtkItemFactory	*factory;
   STStreamMenuItems	*stream_items;
+  GtkWidget		*select_all_item;
+  GtkWidget		*find_item;
+  GtkWidget		*find_next_item;
+  GtkWidget		*find_previous_item;
+  GtkWidget		*search_in_all_categories_item;
   GtkWidget		*stop_item;
   GtkWidget		*refresh_item;
   GtkWidget		*view_tab_icons_item;
@@ -98,12 +104,15 @@ struct _STShellPrivate
   GtkWidget		*statusbox;
 
   GSList		*tabs;
+  char			*find_token;
+  gboolean		find_case_sensitive;
 
   GSList		*tasks;
   STThread		*tune_in_thread;
 
   /* dialogs */
   GtkWidget		*stream_properties;
+  GtkWidget		*find;
   GtkWidget		*preferences;
   GtkWidget		*about;
 };
@@ -184,6 +193,32 @@ static void st_shell_stop (STShell *shell);
 static gboolean st_shell_can_refresh (STShell *shell);
 static void st_shell_refresh (STShell *shell);
 
+static gboolean st_shell_can_select_all (STShell *shell);
+static void st_shell_select_all (STShell *shell);
+
+static gboolean st_shell_can_find (STShell *shell);
+static void st_shell_find (STShell *shell);
+
+static void st_shell_find_notify_h (GObject *object,
+				    GParamSpec *pspec,
+				    gpointer user_data);
+static void st_shell_find_response_h (GtkDialog *dialog,
+				      int response,
+				      gpointer data);
+
+static gboolean st_shell_can_find_next (STShell *shell);
+static void st_shell_find_next (STShell *shell);
+
+static gboolean st_shell_can_find_previous (STShell *shell);
+static void st_shell_find_previous (STShell *shell);
+
+static void st_shell_find_real (STShell *shell,
+				sGtkDirection direction,
+				gboolean wrap_around);
+
+static gboolean st_shell_can_search_in_all_categories (STShell *shell);
+static void st_shell_search_in_all_categories (STShell *shell);
+
 static void st_shell_stream_properties_response_h (GtkDialog *dialog,
 						   int response,
 						   gpointer data);
@@ -401,6 +436,46 @@ st_shell_make_menubar (STShell *shell)
       NULL,					0,
       "<Branch>",				NULL
     },
+    {
+      N_("/Edit/Select _All"),			"<Control>A",
+      st_shell_select_all,			0,
+      "<Item>",					NULL
+    },
+    {
+      "/Edit/separator1",			NULL,
+      NULL,					0,
+      "<Separator>",				NULL
+    },
+    {
+      N_("/Edit/_Find"),			NULL,
+      st_shell_find,				0,
+      "<StockItem>",				GTK_STOCK_FIND
+    },
+    {
+      N_("/Edit/Find Ne_xt"),			"<Control>G",
+      st_shell_find_next,			0,
+      "<Item>",					NULL
+    },
+    {
+      N_("/Edit/Find Pre_vious"),		"<Shift><Control>G",
+      st_shell_find_previous,			0,
+      "<Item>",					NULL
+    },
+    {
+      "/Edit/separator2",			NULL,
+      NULL,					0,
+      "<Separator>",				NULL
+    },
+    {
+      N_("/Edit/_Search in All Categories"),	"<Shift><Control>S",
+      st_shell_search_in_all_categories,	0,
+      "<Item>",					NULL
+    },
+    {
+      "/Edit/separator3",			NULL,
+      NULL,					0,
+      "<Separator>",				NULL
+    },
     {
       N_("/Edit/_Preferences"),			NULL,
       st_shell_present_preferences,		0,
@@ -607,6 +682,11 @@ st_shell_make_menubar (STShell *shell)
 
   /* remember the items we'll need later on */
 
+  shell->priv->select_all_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Select All"));
+  shell->priv->find_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Find"));
+  shell->priv->find_next_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Find Next"));
+  shell->priv->find_previous_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Find Previous"));
+  shell->priv->search_in_all_categories_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Search in All Categories"));
   shell->priv->stop_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Stop"));
   shell->priv->refresh_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Refresh"));
   shell->priv->view_tab_icons_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Tab Icons"));
@@ -1137,6 +1217,11 @@ st_shell_tab_selected (STShell *shell)
 
   if (shell->priv->stream_properties)
     st_stream_properties_dialog_update_sensitivity(ST_STREAM_PROPERTIES_DIALOG(shell->priv->stream_properties));
+  if (shell->priv->find)
+    {
+      sgtk_find_dialog_set_previous_sensitive(SGTK_FIND_DIALOG(shell->priv->find), TRUE);
+      sgtk_find_dialog_set_next_sensitive(SGTK_FIND_DIALOG(shell->priv->find), TRUE);
+    }
 }
 
 static void
@@ -1246,6 +1331,11 @@ st_shell_update_sensitivity (STShell *shell)
 
   /* menubar */
   st_stream_menu_items_update_sensitivity(shell->priv->stream_items);
+  gtk_widget_set_sensitive(shell->priv->select_all_item, st_shell_can_select_all(shell));
+  gtk_widget_set_sensitive(shell->priv->find_item, st_shell_can_find(shell));
+  gtk_widget_set_sensitive(shell->priv->find_next_item, st_shell_can_find_next(shell));
+  gtk_widget_set_sensitive(shell->priv->find_previous_item, st_shell_can_find_previous(shell));
+  gtk_widget_set_sensitive(shell->priv->search_in_all_categories_item, st_shell_can_search_in_all_categories(shell));
   gtk_widget_set_sensitive(shell->priv->stop_item, st_shell_can_stop(shell));
   gtk_widget_set_sensitive(shell->priv->refresh_item, st_shell_can_refresh(shell));
   gtk_widget_set_sensitive(shell->priv->directory_homepage_item, st_shell_can_visit_directory_homepage(shell));
@@ -1336,6 +1426,276 @@ st_shell_refresh (STShell *shell)
   st_browser_tab_refresh(selected_tab);
 }
 
+static gboolean
+st_shell_can_select_all (STShell *shell)
+{
+  STBrowserTab *selected_tab;
+
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
+
+  selected_tab = st_shell_get_selected_tab(shell);
+
+  return selected_tab != NULL;
+}
+
+static void
+st_shell_select_all (STShell *shell)
+{
+  STBrowserTab *selected_tab;
+
+  g_return_if_fail(ST_IS_SHELL(shell));
+  g_return_if_fail(st_shell_can_select_all(shell));
+
+  selected_tab = st_shell_get_selected_tab(shell);
+  st_stream_view_select_all(selected_tab->stream_view);
+}
+
+static gboolean
+st_shell_can_find (STShell *shell)
+{
+  STBrowserTab *selected_tab;
+
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
+
+  selected_tab = st_shell_get_selected_tab(shell);
+
+  return selected_tab != NULL;
+}
+
+static void
+st_shell_find (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  if (shell->priv->find)
+    gtk_window_present(GTK_WINDOW(shell->priv->find));
+  else
+    {
+      gboolean navigation_sensitive;
+
+      shell->priv->find = sgtk_find_dialog_new(GTK_WINDOW(shell->priv->window));
+      g_object_add_weak_pointer(G_OBJECT(shell->priv->find), (gpointer *) &shell->priv->find);
+
+      sgtk_find_dialog_set_token(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_token);
+      sgtk_find_dialog_set_history(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_history);
+      sgtk_find_dialog_set_case_sensitive(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_case_sensitive);
+      sgtk_find_dialog_set_wrap_around(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_wrap_around);
+
+      navigation_sensitive = *st_settings.find_token != 0;
+      sgtk_find_dialog_set_previous_sensitive(SGTK_FIND_DIALOG(shell->priv->find), navigation_sensitive);
+      sgtk_find_dialog_set_next_sensitive(SGTK_FIND_DIALOG(shell->priv->find), navigation_sensitive);
+      
+      g_signal_connect(G_OBJECT(shell->priv->find),
+		       "notify",
+		       G_CALLBACK(st_shell_find_notify_h),
+		       NULL);
+      g_signal_connect(G_OBJECT(shell->priv->find),
+		       "response",
+		       G_CALLBACK(st_shell_find_response_h),
+		       shell);
+
+      gtk_widget_show(shell->priv->find);
+    }
+}
+
+static void
+st_shell_find_notify_h (GObject *object,
+			GParamSpec *pspec,
+			gpointer user_data)
+{
+  sGtkFindDialog *dialog = SGTK_FIND_DIALOG(object);
+  const char *name = g_param_spec_get_name(pspec);
+
+  if (! strcmp(name, "token"))
+    {
+      gboolean navigation_sensitive;
+
+      g_free(st_settings.find_token);
+      st_settings.find_token = g_strdup(sgtk_find_dialog_get_token(dialog));
+
+      navigation_sensitive = *st_settings.find_token != 0;
+      sgtk_find_dialog_set_previous_sensitive(dialog, navigation_sensitive);
+      sgtk_find_dialog_set_next_sensitive(dialog, navigation_sensitive);
+    }
+  else if (! strcmp(name, "history"))
+    {
+      sg_pointers_free(st_settings.find_history);
+      st_settings.find_history = sgtk_find_dialog_get_history(dialog);
+
+      if (g_slist_length(st_settings.find_history) > ST_SETTINGS_FIND_HISTORY_MAX_LENGTH)
+	{
+	  GSList *elem;
+
+	  elem = g_slist_nth(st_settings.find_history, ST_SETTINGS_FIND_HISTORY_MAX_LENGTH - 1);
+	  g_return_if_fail(elem != NULL);
+
+	  sg_pointers_free(elem->next);
+	  elem->next = NULL;
+
+	  sgtk_find_dialog_set_history(dialog, st_settings.find_history);
+	}
+    }
+  else if (! strcmp(name, "case-sensitive"))
+    {
+      st_settings.find_case_sensitive = sgtk_find_dialog_get_case_sensitive(dialog);
+      sgtk_find_dialog_set_previous_sensitive(dialog, TRUE);
+      sgtk_find_dialog_set_next_sensitive(dialog, TRUE);
+    }
+  else if (! strcmp(name, "wrap-around"))
+    {
+      st_settings.find_wrap_around = sgtk_find_dialog_get_wrap_around(dialog);
+      if (st_settings.find_wrap_around)
+	{
+	  sgtk_find_dialog_set_previous_sensitive(dialog, TRUE);
+	  sgtk_find_dialog_set_next_sensitive(dialog, TRUE);
+	}
+    }
+}
+
+static void
+st_shell_find_response_h (GtkDialog *dialog,
+			  int response,
+			  gpointer data)
+{
+  STShell *shell = data;
+  sGtkDirection direction;
+
+  switch (response)
+    {
+    case SGTK_RESPONSE_PREVIOUS:
+      direction = SGTK_PREVIOUS;
+      break;
+      
+    case SGTK_RESPONSE_NEXT:
+      direction = SGTK_NEXT;
+      break;
+
+    case GTK_RESPONSE_DELETE_EVENT:
+    case GTK_RESPONSE_CLOSE:
+      gtk_widget_destroy(GTK_WIDGET(dialog));
+      return;			/* finish */
+
+    default:
+      g_return_if_reached();
+    }
+
+  g_free(shell->priv->find_token);
+  shell->priv->find_token = g_strdup(sgtk_find_dialog_get_token(SGTK_FIND_DIALOG(dialog)));
+  shell->priv->find_case_sensitive = sgtk_find_dialog_get_case_sensitive(SGTK_FIND_DIALOG(dialog));
+  st_shell_find_real(shell, direction, sgtk_find_dialog_get_wrap_around(SGTK_FIND_DIALOG(dialog)));
+}
+
+static gboolean
+st_shell_can_find_next (STShell *shell)
+{
+  return st_shell_can_find(shell) && shell->priv->find_token;
+}
+
+static void
+st_shell_find_next (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  st_shell_find_real(shell, SGTK_NEXT, TRUE);
+}
+
+static gboolean
+st_shell_can_find_previous (STShell *shell)
+{
+  return st_shell_can_find(shell) && shell->priv->find_token;
+}
+
+static void
+st_shell_find_previous (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  st_shell_find_real(shell, SGTK_PREVIOUS, TRUE);
+}
+
+static void
+st_shell_find_real (STShell *shell,
+		    sGtkDirection direction,
+		    gboolean wrap_around)
+{
+  STBrowserTab *selected_tab;
+  gboolean found;
+
+  g_return_if_fail(ST_IS_SHELL(shell));
+  
+  selected_tab = st_shell_get_selected_tab(shell);
+  found = st_stream_view_find(selected_tab->stream_view,
+			      direction,
+			      shell->priv->find_token,
+			      shell->priv->find_case_sensitive,
+			      wrap_around);
+  
+  if (shell->priv->find)
+    {
+      if (found)
+	switch (direction)
+	  {
+	  case SGTK_PREVIOUS:
+	    sgtk_find_dialog_set_next_sensitive(SGTK_FIND_DIALOG(shell->priv->find), TRUE);
+	    break;
+	    
+	  case SGTK_NEXT:
+	    sgtk_find_dialog_set_previous_sensitive(SGTK_FIND_DIALOG(shell->priv->find), TRUE);
+	    break;
+	
+	  default:
+	    g_return_if_reached();
+	  }
+      else
+	switch (direction)
+	  {
+	  case SGTK_PREVIOUS:
+	    sgtk_find_dialog_set_previous_sensitive(SGTK_FIND_DIALOG(shell->priv->find), FALSE);
+	    break;
+	    
+	  case SGTK_NEXT:
+	    sgtk_find_dialog_set_next_sensitive(SGTK_FIND_DIALOG(shell->priv->find), FALSE);
+	    break;
+	
+	  default:
+	    g_return_if_reached();
+	  }
+    }
+}
+
+static gboolean
+st_shell_can_search_in_all_categories (STShell *shell)
+{
+  STBrowserTab *selected_tab;
+
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
+
+  selected_tab = st_shell_get_selected_tab(shell);
+
+  return selected_tab
+    && st_handler_get_stock_category(selected_tab->handler, ST_CATEGORY_BAG_SEARCH);
+}
+
+static void
+st_shell_search_in_all_categories (STShell *shell)
+{
+  STBrowserTab *selected_tab;
+  STCategoryBag *search_category;
+
+  g_return_if_fail(ST_IS_SHELL(shell));
+  g_return_if_fail(st_shell_can_search_in_all_categories(shell));
+
+  selected_tab = st_shell_get_selected_tab(shell);
+  g_return_if_fail(selected_tab != NULL);
+
+  search_category = st_handler_get_stock_category(selected_tab->handler, ST_CATEGORY_BAG_SEARCH);
+  g_return_if_fail(search_category != NULL);
+
+  st_category_bag_select(search_category);
+  st_category_view_select_category(selected_tab->category_view, search_category);
+  st_browser_tab_refresh(selected_tab);
+}
+
 static void
 st_shell_launch_stream_task (STShell *shell, STStreamTask task)
 {
@@ -1890,6 +2250,11 @@ st_shell_stream_selection_changed_h (STStreamView *view, gpointer user_data)
       st_stream_properties_dialog_update_sensitivity(ST_STREAM_PROPERTIES_DIALOG(shell->priv->stream_properties));
       st_shell_stream_properties_update_stream(shell);
     }
+  if (shell->priv->find)
+    {
+      sgtk_find_dialog_set_previous_sensitive(SGTK_FIND_DIALOG(shell->priv->find), TRUE);
+      sgtk_find_dialog_set_next_sensitive(SGTK_FIND_DIALOG(shell->priv->find), TRUE);
+    }
 }
 
 static void
