@@ -1,5 +1,5 @@
 /*
- * $Id: st-splash.c,v 1.3.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-splash.c,v 1.3.2.2 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,9 +32,9 @@
  */
 
 #include "config.h"
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include "art/streamtuner.h"
+#include "gettext.h"
 #include "sgtk-hig.h"
 #include "st-splash.h"
 #include "st-util.h"
