@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-properties-dialog.c,v 1.86.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-stream-properties-dialog.c,v 1.86.2.2 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -33,8 +33,8 @@
 
 #include "config.h"
 #include <string.h>
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
+#include "gettext.h"
 #include "sg-util.h"
 #include "st-stream-properties-dialog.h"
 #include "st-handler.h"
