@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-view.c,v 1.132.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-stream-view.c,v 1.132.2.7 2004/07/24 17:32:42 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -66,6 +66,9 @@ struct _STStreamViewPrivate
   STHandler		*handler;
   STStreamMenuItems	*menu_items;
   unsigned int		selection_changed_hid;
+
+  gboolean		find_iter_valid;
+  GtkTreeIter		find_iter;
 };
   
 /*** variable declarations ***************************************************/
@@ -525,7 +528,22 @@ st_stream_view_selection_changed_h (GtkTreeSelection *selection,
 				    gpointer user_data)
 {
   STStreamView *view = user_data;
+  GSList *selected_streams;
 
+  selected_streams = st_stream_view_get_selected_streams(view);
+  if (selected_streams)
+    {
+      GSList *last = g_slist_last(selected_streams);
+      STStreamBag *bag = last->data;
+
+      view->priv->find_iter_valid = TRUE;
+      view->priv->find_iter = bag->iter;
+
+      sg_objects_free(selected_streams);
+    }
+  else
+    view->priv->find_iter_valid = FALSE;
+  
   g_signal_emit(view, stream_view_signals[SELECTION_CHANGED], 0);
 }
 
@@ -546,6 +564,10 @@ st_stream_view_update_sensitivity (STStreamView *view)
     st_stream_menu_items_update_sensitivity(view->priv->menu_items);
 }
 
+/*
+ * Select the iter belonging to stream BAG, and let that trigger the
+ * emission of a selection-changed signal.
+ */
 void
 st_stream_view_select_stream (STStreamView *view, STStreamBag *bag)
 {
@@ -556,10 +578,8 @@ st_stream_view_select_stream (STStreamView *view, STStreamBag *bag)
 
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
 
-  g_signal_handler_block(selection, view->priv->selection_changed_hid);
   gtk_tree_selection_unselect_all(selection);
   gtk_tree_selection_select_iter(selection, &bag->iter);
-  g_signal_handler_unblock(selection, view->priv->selection_changed_hid);
 }
 
 void
@@ -588,12 +608,9 @@ st_stream_view_can_select_previous (STStreamView *view)
   if (st_stream_view_get_first_selection(view, &iter))
     {
       GtkTreeModel *model;
-      GtkTreePath *path;
       
       model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
-      path = gtk_tree_model_get_path(model, &iter);
-      can = gtk_tree_path_prev(path);
-      gtk_tree_path_free(path);
+      can = sgtk_tree_model_iter_prev(model, &iter);
     }
 
   return can;
@@ -741,6 +758,8 @@ st_stream_view_set_store (STStreamView *view, STStreamStore *store)
   g_return_if_fail(ST_IS_STREAM_VIEW(view));
   
   gtk_tree_view_set_model(GTK_TREE_VIEW(view), GTK_TREE_MODEL(store));
+  view->priv->find_iter_valid = FALSE;
+
   g_signal_emit(view, stream_view_signals[SELECTION_CHANGED], 0);
 }
 
@@ -801,3 +820,82 @@ st_stream_view_has_selected_streams (STStreamView *view)
 
   return has;
 }
+
+void
+st_stream_view_select_all (STStreamView *view)
+{
+  GtkTreeSelection *selection;
+
+  g_return_if_fail(ST_IS_STREAM_VIEW(view));
+
+  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
+  gtk_tree_selection_select_all(selection);
+}
+
+gboolean
+st_stream_view_find (STStreamView *view,
+		     sGtkDirection direction,
+		     const char *token,
+		     gboolean case_sensitive,
+		     gboolean wrap_around)
+{
+  GtkTreeModel *model;
+  gboolean found = FALSE;
+
+  g_return_val_if_fail(ST_IS_STREAM_VIEW(view), FALSE);
+  g_return_val_if_fail(token != NULL, FALSE);
+
+  model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
+  if (model)
+    {
+      gboolean valid;
+      GtkTreeIter iter;
+      gboolean edge_hit = FALSE;
+
+      if (view->priv->find_iter_valid)
+	{
+	  iter = view->priv->find_iter;
+	  valid = sgtk_tree_model_iter_move(model, &iter, direction);
+	}
+      else
+	valid = gtk_tree_model_get_iter_first(model, &iter);
+
+      while (valid)
+	{
+	  STStreamBag *bag;
+
+	  gtk_tree_model_get(model, &iter, ST_STREAM_STORE_COLUMN_BAG, &bag, -1);
+	  found = st_stream_bag_matches(bag, token, case_sensitive);
+	  if (found)
+	    {
+	      st_stream_view_select_stream(view, bag);
+	      st_stream_view_present_stream(view, bag);
+	    }
+	  g_object_unref(bag);
+
+	  if (found)
+	    break;
+
+	  valid = sgtk_tree_model_iter_move(model, &iter, direction);
+	  if (! valid && wrap_around && ! edge_hit)
+	    {
+	      edge_hit = TRUE;
+	      switch (direction)
+		{
+		case SGTK_PREVIOUS:
+		  valid = sgtk_tree_model_get_iter_last(model, &iter);
+		  break;
+
+		case SGTK_NEXT:
+		  valid = gtk_tree_model_get_iter_first(model, &iter);
+		  break;
+
+		default:
+		  g_return_val_if_reached(FALSE);
+		}
+	    }
+	}
+    }
+
+  return found;
+}
