@@ -1,5 +1,5 @@
 /*
- * $Id: st-thread.c,v 1.33.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-thread.c,v 1.33.2.3 2004/07/25 18:42:04 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -241,7 +241,7 @@ st_thread_validate_callback_return (STThread *thread,
 	  GDK_THREADS_LEAVE();
 	  
 	  st_error_dialog(_("A callback error has occurred."),
-			  _("The callback reported that the task was aborted but it wasn't."));
+			  _("The callback reported that the task was aborted but it was not."));
 	}
     }
 }
