@@ -1,5 +1,5 @@
 /*
- * $Id: st-transfer.c,v 1.73.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-transfer.c,v 1.73.2.7 2004/07/26 14:38:27 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,15 +34,17 @@
 #include "config.h"
 #include <string.h>
 #include <curl/curl.h>
+#ifndef ST_REGRESSION_TEST
 #include <gtk/gtk.h>
 #include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-auth-dialog.h"
 #include "st-dialog-api.h"
 #include "st-settings.h"
-#include "st-transfer.h"
 #include "st-thread.h"
 #include "st-main.h"
+#endif /* ST_REGRESSION_TEST */
+#include "st-transfer.h"
 
 #define AGENT_STRING			"streamtuner"
 
@@ -69,7 +71,9 @@ typedef size_t (CurlCallback) (const char *buffer,
 
 typedef struct
 {
+#ifndef ST_REGRESSION_TEST
   STThread			*thread;
+#endif /* ST_REGRESSION_TEST */
   double			downloaded;
 
   const char			*url;
@@ -100,6 +104,8 @@ typedef struct
   STTransfer			*transfer;
 
   GString			*line;
+  char				terminator[2]; /* \n\0, \r\n or \r\0 */
+
   STTransferLineCallback	*line_cb;
   gpointer			line_cb_data;
 } STTransferLineData;
@@ -111,7 +117,9 @@ static gboolean st_transfer_perform (STTransfer *transfer, GError **err);
 static gboolean st_transfer_set_proxy_settings (STTransfer *transfer);
 static void st_transfer_free_proxy_settings (STTransfer *transfer);
 
+#ifndef ST_REGRESSION_TEST
 static char *st_transfer_password_prompt (const char *username);
+#endif /* ST_REGRESSION_TEST */
 
 static gboolean st_transfer_progress_cb (gpointer data,
 					 double dltotal,
@@ -125,6 +133,15 @@ static gboolean st_transfer_session_get_internal (STTransferSession *session,
 						  char **headers,
 						  char **body,
 						  GError **err);
+
+static void st_transfer_line_data_init (STTransferLineData *data,
+					STTransfer *transfer,
+					STTransferLineCallback *cb,
+					gpointer cb_data);
+static void st_transfer_line_data_flush (STTransferLineData *data);
+static void st_transfer_line_data_free (STTransferLineData *data,
+					gboolean flush);
+
 static gboolean st_transfer_session_get_by_line_internal (STTransferSession *session,
 							  const char *url,
 							  unsigned int flags,
@@ -437,6 +454,47 @@ st_transfer_get_lines_with_session (STTransferSession *session,
   return st_transfer_session_get_by_line_internal(session, url, 0, NULL, NULL, cb, data, err);
 }
 
+static void
+st_transfer_line_data_init (STTransferLineData *data,
+			    STTransfer *transfer,
+			    STTransferLineCallback *cb,
+			    gpointer cb_data)
+{
+  g_return_if_fail(data != NULL);
+  g_return_if_fail(transfer != NULL);
+
+  data->transfer = transfer;
+  data->line = g_string_new(NULL);
+  *data->terminator = 0;
+  data->line_cb = cb;
+  data->line_cb_data = cb_data;
+}
+
+static void
+st_transfer_line_data_flush (STTransferLineData *data)
+{
+  g_return_if_fail(data != NULL);
+
+  if (data->transfer->flags & ST_TRANSFER_PASS_NEWLINE && *data->terminator)
+    g_string_append_len(data->line, data->terminator, sizeof(data->terminator));
+
+  data->line_cb(data->line->str, data->line_cb_data);
+
+  g_string_truncate(data->line, 0);
+  *data->terminator = 0;
+}
+
+static void
+st_transfer_line_data_free (STTransferLineData *data, gboolean flush)
+{
+  g_return_if_fail(data != NULL);
+
+  if (flush && *data->line->str)
+    st_transfer_line_data_flush(data);
+
+  g_string_free(data->line, TRUE);
+}
+
 static gboolean
 st_transfer_session_get_by_line_internal (STTransferSession *session,
 					  const char *url,
@@ -461,11 +519,7 @@ st_transfer_session_get_by_line_internal (STTransferSession *session,
 
   if (header_cb)
     {
-      header_line_data.transfer = &transfer;
-      header_line_data.line = g_string_new(NULL);
-      header_line_data.line_cb = header_cb;
-      header_line_data.line_cb_data = header_data;
-
+      st_transfer_line_data_init(&header_line_data, &transfer, header_cb, header_data);
       transfer.header_cb = st_transfer_session_get_by_line_cb;
       transfer.header_data = &header_line_data;
     }
@@ -477,11 +531,7 @@ st_transfer_session_get_by_line_internal (STTransferSession *session,
    
   if (body_cb)
     {
-      body_line_data.transfer = &transfer;
-      body_line_data.line = g_string_new(NULL);
-      body_line_data.line_cb = body_cb;
-      body_line_data.line_cb_data = body_data;
-      
+      st_transfer_line_data_init(&body_line_data, &transfer, body_cb, body_data);
       transfer.body_cb = st_transfer_session_get_by_line_cb;
       transfer.body_data = &body_line_data;
     }
@@ -494,9 +544,9 @@ st_transfer_session_get_by_line_internal (STTransferSession *session,
   status = st_transfer_perform(&transfer, err);
   
   if (header_cb)
-    g_string_free(header_line_data.line, TRUE);
+    st_transfer_line_data_free(&header_line_data, status);
   if (body_cb)
-    g_string_free(body_line_data.line, TRUE);
+    st_transfer_line_data_free(&body_line_data, status);
   
   return status;
 }
@@ -510,33 +560,41 @@ st_transfer_perform (STTransfer *transfer, GError **err)
   g_return_val_if_fail(transfer->url != NULL, FALSE);
   g_return_val_if_fail(transfer->session != NULL, FALSE);
 
+#ifndef ST_REGRESSION_TEST
   transfer->thread = st_thread_get();
   g_return_val_if_fail(transfer->thread != NULL, FALSE);
 
   if (st_thread_is_aborted(transfer->thread))
     return FALSE;
+#endif /* ST_REGRESSION_TEST */
 
   transfer->downloaded = 0;
 
+#ifndef ST_REGRESSION_TEST
   GDK_THREADS_ENTER();
   st_thread_set_progress(transfer->thread, 0);
   gdk_flush();
   GDK_THREADS_LEAVE();
+#endif /* ST_REGRESSION_TEST */
 
   if (! st_transfer_set_proxy_settings(transfer))
     {
+#ifndef ST_REGRESSION_TEST
       GDK_THREADS_ENTER();
       st_thread_abort(transfer->thread);
       gdk_flush();
       GDK_THREADS_LEAVE();
+#endif /* ST_REGRESSION_TEST */
       
       return FALSE;		/* aborted */
     }
 
+#ifndef ST_REGRESSION_TEST
   GDK_THREADS_ENTER();
   st_thread_printf(transfer->thread, _("Connecting to %s..."), transfer->url);
   gdk_flush();
   GDK_THREADS_LEAVE();
+#endif /* ST_REGRESSION_TEST */
   
   curl_easy_setopt(transfer->session->handle, CURLOPT_USERAGENT, AGENT_STRING);
   curl_easy_setopt(transfer->session->handle, CURLOPT_URL, transfer->url);
@@ -564,7 +622,10 @@ st_transfer_perform (STTransfer *transfer, GError **err)
 
   if (status != CURLE_OK
       && status != CURLE_ABORTED_BY_CALLBACK
-      && ! st_thread_is_aborted(transfer->thread))
+#ifndef ST_REGRESSION_TEST
+      && ! st_thread_is_aborted(transfer->thread)
+#endif /* ST_REGRESSION_TEST */
+      )
     g_set_error(err, 0, 0, "%s", transfer->error); /* failure which isn't abort */
 
   return status == CURLE_OK;
@@ -582,6 +643,7 @@ st_transfer_set_proxy_settings (STTransfer *transfer)
   transfer->proxy_port = 0;
   transfer->proxy_userpwd = NULL;
 
+#ifndef ST_REGRESSION_TEST
   G_LOCK(st_settings);
 
   /*
@@ -623,6 +685,7 @@ st_transfer_set_proxy_settings (STTransfer *transfer)
     }
 
   G_UNLOCK(st_settings);
+#endif /* ST_REGRESSION_TEST */
 
   return status;
 }
@@ -649,9 +712,12 @@ st_transfer_progress_cb (gpointer data,
 			 double ultotal,
 			 double ulnow)
 {
+#ifndef ST_REGRESSION_TEST
   STTransfer *transfer = data;
+#endif /* ST_REGRESSION_TEST */
   gboolean aborted = FALSE;
 
+#ifndef ST_REGRESSION_TEST
   aborted = st_thread_is_aborted(transfer->thread);
   if (! aborted)
     {
@@ -680,10 +746,12 @@ st_transfer_progress_cb (gpointer data,
       gdk_flush();
       GDK_THREADS_LEAVE();
     }
+#endif /* ST_REGRESSION_TEST */
 
   return aborted;
 }
 
+#ifndef ST_REGRESSION_TEST
 static char *
 st_transfer_password_prompt (const char *username)
 {
@@ -705,6 +773,7 @@ st_transfer_password_prompt (const char *username)
 
   return password;
 }
+#endif /* ST_REGRESSION_TEST */
 
 static size_t
 st_transfer_session_get_cb (const char *buffer,
@@ -745,34 +814,38 @@ st_transfer_session_get_by_line_cb (const char *buffer,
   STTransferLineData *line_data = data;
   size_t len;
   int start = 0;
-  int i = 0;
+  int i;
 
   len = size * nitems;
 
-  /* handle lf (UNIX), crlf (DOS) and cr (Mac) */
-  while (i < len)
-    if (buffer[i] == '\n' || buffer[i] == '\r')
-      {
-	int newline_len;
+  /* handles lf (UNIX), crlf (DOS) and cr (Mac) terminators */
+  for (i = 0; i < len; i++)
+    {
+      gboolean processed = FALSE;
 
-	newline_len = buffer[i] == '\r' && i < len && buffer[i + 1] == '\n'
-	  ? 2			/* crlf */
-	  : 1;			/* cr or lf */
+      if (*line_data->terminator)
+	{
+	  if (buffer[i] == '\n' && *line_data->terminator == '\r')
+	    {
+	      line_data->terminator[1] = '\n';
+	      processed = TRUE;
+	      start = i + 1;
+	    }
+	  else
+	    start = i;
 
-	g_string_append_len(line_data->line, &buffer[start], i - start);
-	if (line_data->transfer->flags & ST_TRANSFER_PASS_NEWLINE)
-	  g_string_append_len(line_data->line, &buffer[i], newline_len);
+	  st_transfer_line_data_flush(line_data);
+	}
 
-	line_data->line_cb(line_data->line->str, line_data->line_cb_data);
-	g_string_truncate(line_data->line, 0);
-
-	start = i += newline_len;
-      }
-    else
-      i++;
-  
+      if (! processed && (buffer[i] == '\n' || buffer[i] == '\r'))
+	{
+	  g_string_append_len(line_data->line, buffer + start, i - start);
+	  line_data->terminator[0] = buffer[i];
+	  line_data->terminator[1] = 0;
+	}
+    }
   if (start < len)
-    g_string_append_len(line_data->line, &buffer[start], len - start);
+    g_string_append_len(line_data->line, buffer + start, len - start);
   
   return len;
 }
@@ -798,8 +871,12 @@ st_transfer_init (void)
 {
   if (curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK)
     {
+#ifdef ST_REGRESSION_TEST
+      g_critical("unable to initialize libcurl");
+#else
       st_error_dialog(_("A fatal error has occurred."),
 		      _("Unable to initialize the curl library."));
       exit(1);
+#endif ST_REGRESSION_TEST
     }
 }
